# Acknowledgements

GLFW exists because people around the world donated their time and lent their
skills.  This list only includes contributions to the main repository and
excludes other invaluable contributions like language bindings and text and
video tutorials.

 - Bobyshev Alexander
 - Laurent Aphecetche
 - Matt Arsenault
 - ashishgamedev
 - David Avedissian
 - Keith Bauer
 - John Bartholomew
 - Coşku Baş
 - Niklas Behrens
 - Andrew Belt
 - Nevyn Bengtsson
 - Niklas Bergström
 - Denis Bernard
 - BiBi
 - Doug Binks
 - blanco
 - Waris Boonyasiriwat
 - Kyle Brenneman
 - Rok Breulj
 - TheBrokenRail
 - Kai Burjack
 - Martin Capitanio
 - Nicolas Caramelli
 - David Carlier
 - Arturo Castro
 - Chi-kwan Chan
 - TheChocolateOre
 - Joseph Chua
 - Ian Clarkson
 - Michał Cichoń
 - Lambert Clara
 - Anna Clarke
 - Josh Codd
 - Yaron Cohen-Tal
 - Omar Cornut
 - Andrew Corrigan
 - Bailey Cosier
 - Noel Cower
 - CuriouserThing
 - Jason Daly
 - danhambleton
 - Jarrod Davis
 - Olivier Delannoy
 - Paul R. Deppe
 - Michael Dickens
 - Роман Донченко
 - Mario Dorn
 - Wolfgang Draxinger
 - Jonathan Dummer
 - Ralph Eastwood
 - Fredrik Ehnbom
 - Robin Eklind
 - Jan Ekström
 - Siavash Eliasi
 - TheExileFox
 - Nikita Fediuchin
 - Felipe Ferreira
 - Michael Fogleman
 - Jason Francis
 - Gerald Franz
 - Mário Freitas
 - GeO4d
 - Marcus Geelnard
 - ghuser404
 - Charles Giessen
 - Ryan C. Gordon
 - Stephen Gowen
 - Kovid Goyal
 - Kevin Grandemange
 - Eloi Marín Gratacós
 - Stefan Gustavson
 - Andrew Gutekanst
 - Stephen Gutekanst
 - Jonathan Hale
 - hdf89shfdfs
 - Sylvain Hellegouarch
 - Matthew Henry
 - heromyth
 - Lucas Hinderberger
 - Paul Holden
 - Hajime Hoshi
 - Warren Hu
 - Charles Huber
 - Brent Huisman
 - illustris
 - InKryption
 - IntellectualKitty
 - Aaron Jacobs
 - JannikGM
 - Erik S. V. Jansson
 - jjYBdx4IL
 - Toni Jovanoski
 - Arseny Kapoulkine
 - Cem Karan
 - Osman Keskin
 - Koray Kilinc
 - Josh Kilmer
 - Byunghoon Kim
 - Cameron King
 - Peter Knut
 - Christoph Kubisch
 - Yuri Kunde Schlesner
 - Rokas Kupstys
 - Konstantin Käfer
 - Eric Larson
 - Francis Lecavalier
 - Jong Won Lee
 - Robin Leffmann
 - Glenn Lewis
 - Shane Liesegang
 - Anders Lindqvist
 - Leon Linhart
 - Marco Lizza
 - Eyal Lotem
 - Aaron Loucks
 - Luflosi
 - lukect
 - Tristam MacDonald
 - Hans Mackowiak
 - Дмитри Малышев
 - Zbigniew Mandziejewicz
 - Adam Marcus
 - Célestin Marot
 - Kyle McDonald
 - David V. McKay
 - David Medlock
 - Bryce Mehring
 - Jonathan Mercier
 - Marcel Metz
 - Liam Middlebrook
 - Ave Milia
 - Jonathan Miller
 - Kenneth Miller
 - Bruce Mitchener
 - Jack Moffitt
 - Ravi Mohan
 - Jeff Molofee
 - Alexander Monakov
 - Pierre Morel
 - Jon Morton
 - Pierre Moulon
 - Martins Mozeiko
 - James Murphy
 - Julian Møller
 - ndogxj
 - F. Nedelec
 - Kristian Nielsen
 - Joel Niemelä
 - Kamil Nowakowski
 - onox
 - Denis Ovod
 - Ozzy
 - Andri Pálsson
 - Peoro
 - Braden Pellett
 - Christopher Pelloux
 - Arturo J. Pérez
 - Vladimir Perminov
 - Olivier Perret
 - Anthony Pesch
 - Orson Peters
 - Emmanuel Gil Peyrot
 - Cyril Pichard
 - Pilzschaf
 - Keith Pitt
 - Stanislav Podgorskiy
 - Konstantin Podsvirov
 - Nathan Poirier
 - Alexandre Pretyman
 - Pablo Prietz
 - przemekmirek
 - pthom
 - Martin Pulec
 - Guillaume Racicot
 - Philip Rideout
 - Eddie Ringle
 - Max Risuhin
 - Jorge Rodriguez
 - Luca Rood
 - Ed Ropple
 - Aleksey Rybalkin
 - Mikko Rytkönen
 - Riku Salminen
 - Brandon Schaefer
 - Sebastian Schuberth
 - Christian Sdunek
 - Matt Sealey
 - Steve Sexton
 - Arkady Shapkin
 - Ali Sherief
 - Yoshiki Shibukawa
 - Dmitri Shuralyov
 - Joao da Silva
 - Daniel Sieger
 - Daniel Skorupski
 - Slemmie
 - Bradley Smith
 - Cliff Smolinsky
 - Patrick Snape
 - Erlend Sogge Heggen
 - Olivier Sohn
 - Julian Squires
 - Johannes Stein
 - Pontus Stenetorp
 - Michael Stocker
 - Justin Stoecker
 - Elviss Strazdins
 - Paul Sultana
 - Nathan Sweet
 - TTK-Bandit
 - Sergey Tikhomirov
 - Arthur Tombs
 - TronicLabs
 - Ioannis Tsakpinis
 - Samuli Tuomola
 - Matthew Turner
 - urraka
 - Elias Vanderstuyft
 - Stef Velzel
 - Jari Vetoniemi
 - Ricardo Vieira
 - Nicholas Vitovitch
 - Simon Voordouw
 - Corentin Wallez
 - Torsten Walluhn
 - Patrick Walton
 - Xo Wang
 - Jay Weisskopf
 - Frank Wille
 - Richard A. Wilkes
 - Tatsuya Yatagawa
 - Ryogo Yoshimura
 - Rácz Zalán
 - Lukas Zanner
 - Andrey Zholos
 - Aihui Zhu
 - Santi Zupancic
 - Jonas Ådahl
 - Lasse Öörni
 - Leonard König
 - All the unmentioned and anonymous contributors in the GLFW community, for bug
   reports, patches, feedback, testing and encouragement

